# -*- coding: utf-8 -*-
import random

import mod.client.extraClientApi as clientApi
import testModelScript.modelConst as ModelConst
import testModelScript.ui.uiMgr as uiMgr
from mod_log import logger

ClientSystem = clientApi.GetClientSystemCls()


class ModelClientSystem(ClientSystem):
    """
    该mod的客户端类
    根据服务端推送下来的数据显示通用显示界面
    """

    def __init__(self, namespace, systemName):
        ClientSystem.__init__(self, namespace, systemName)
        self.ListenForEvent(clientApi.GetEngineNamespace(), clientApi.GetEngineSystemName(), "OnLocalPlayerStopLoading", self, self.OnStopLoading)
        self.ListenForEvent(ModelConst.ModName, ModelConst.ServerSystemName, "OnChangeLocalModelEvent", self, self.OnChangeLocalModel)
        self.ListenForEvent(clientApi.GetEngineNamespace(), clientApi.GetEngineSystemName(), "AddEntityClientEvent", self, self.OnAddEntity)

    def OnChangeLocalModel(self, args):
        playerId = clientApi.GetLocalPlayerId()
        # 更换模型贴图
        actorRenderComp = clientApi.GetEngineCompFactory().CreateActorRender(playerId)
        actorRenderComp.AddPlayerGeometry('default', "geometry.player")
        actorRenderComp.AddPlayerTexture('default', "textures/entity/player")
        actorRenderComp.RebuildPlayerRender()

    def OnStopLoading(self, args):
        # query节点注册时，为全局属性，创建的QueryComp应传入世界参数
        query_comp = clientApi.GetEngineCompFactory().CreateQueryVariable(clientApi.GetLevelId())
        query_comp.Register('query.mod.custom_pig', 0.0)
        self.NotifyToServer("ClientStopLoadingEvent", {})

    def OnAddEntity(self, args):
        entity_id = args['id']
        identifier = args['engineTypeStr']
        if identifier != 'minecraft:pig':
            return
        # query节点在某个实体实例被设置是，创建的QueryComp应传入实体ID参数
        query_comp = clientApi.GetEngineCompFactory().CreateQueryVariable(entity_id)
        # 50%概率创建一个黄猪。若需要全部玩家看到该实体都为黄猪，需在服务端做好同步处理，并广播至每个客户端。
        if random.randint(0, 100) < 50:
            query_comp.Set('query.mod.custom_pig', 1.0)

    def Destroy(self):
        self.UnListenForEvent(clientApi.GetEngineNamespace(), clientApi.GetEngineSystemName(), "OnLocalPlayerStopLoading", self, self.OnStopLoading)
        self.UnListenForEvent(clientApi.GetEngineNamespace(), clientApi.GetEngineSystemName(), "AddEntityClientEvent", self, self.OnAddEntity)
        self.UnListenForEvent(ModelConst.ModName, ModelConst.ServerSystemName, "OnChangeLocalModelEvent", self, self.OnChangeLocalModel)
